@@ -103,7 +103,7 @@ class PwmanCli(cmd.Cmd):
         return getinput("Username: ", default)
 
     def get_password(self, default=""):
-        password = getinput("Password (Blank to generate): ", default)
+        password = getpassword("Password (Blank to generate): ", _defaultwidth, False)
         if len(password) == 0:
             length = getinput("Password length (default 7): ", "7")
             length = int(length)
@@ -217,6 +217,8 @@ class PwmanCli(cmd.Cmd):
         except Exception, e:
             self.error(e)
 
+    def do_e(self, arg):
+        self.do_edit(arg)
 
     def do_edit(self, arg):
         ids = self.get_ids(arg)
@@ -296,6 +298,12 @@ class PwmanCli(cmd.Cmd):
         except Exception, e:
             self.error(e)
 
+    def do_h(self, arg):
+        self.do_help(arg)
+
+    def do_n(self, arg):
+        self.do_new(arg)
+
     def do_new(self, arg):
         try:
             username = self.get_username()
@@ -310,6 +318,9 @@ class PwmanCli(cmd.Cmd):
         except Exception, e:
             self.error(e)
 
+    def do_p(self, arg):
+        self.do_print(arg)
+
     def do_print(self, arg):
         for i in self.get_ids(arg):
             try:
@@ -334,6 +345,9 @@ class PwmanCli(cmd.Cmd):
          except Exception, e:
              self.error(e)
 
+    def do_l(self, args):
+        self.do_list(args)
+
     def do_ls(self, args):
         self.do_list(args)
         
@@ -438,17 +452,32 @@ class PwmanCli(cmd.Cmd):
         print "List nodes that match current filter. ls is an alias."
 
     def help_EOF(self):
-        self.help_quit()
+        self.help_exit()
 
     def help_delete(self):
         self.usage("delete <ID> ...")
         print "Deletes nodes. rm is an alias."
         self._mult_id_help()
 
+    def help_h(self):
+        self.help_help()
+
     def help_help(self):
         self.usage("help [topic]")
         print "Prints a help message for a command."
-    
+
+    def help_e(self):
+        self.help_edit()
+
+    def help_n(self):
+        self.help_new()
+
+    def help_p(self):
+        self.help_print()
+
+    def help_l(self):
+        self.help_list()
+
     def help_edit(self):
         self.usage("edit <ID> ... ")
         print "Edits a nodes."
@@ -538,14 +567,11 @@ class PwmanCli(cmd.Cmd):
             readline.read_history_file(self._historyfile)
         except Exception, e:
             pass
-        
-        _colors = True
 
         self.prompt = "pwman> "
 
 
 _defaultwidth = 10
-_colors = True
 
 def getonechar(question, width=_defaultwidth):
     question = "%s " % (question)
@@ -579,7 +605,8 @@ def getyesno(question, defaultyes=False, width=_defaultwidth):
         return False
     else:
         return getyesno(question, defaultyes, width)
-            
+
+
 def getinput(question, default="", completer=None, width=_defaultwidth):
     if (not _readline_available):
         return raw_input(question.ljust(width))
@@ -595,11 +622,23 @@ def getinput(question, default="", completer=None, width=_defaultwidth):
         readline.set_startup_hook()
         return x
 
-def getpassword(question, width=_defaultwidth):
-    return getpass.getpass(question.ljust(width))
+def getpassword(question, width=_defaultwidth, echo=False):
+    if echo:
+        print question.ljust(width),
+        return sys.stdin.readline().rstrip()
+    else:
+        
+        while 1:
+            a1 = getpass.getpass(question.ljust(width))
+            a2 = getpass.getpass("[Repeat] %s" % (question.ljust(width)))
+            if a1 == a2:
+                return a1
+            else:
+                print "Passwords don't match. Try again."
+        
         
 def typeset(text, color, bold=False, underline=False):
-    if (not _colors):
+    if not config.get_value("Global", "colors") == 'yes':
         return text
     if (bold):
         bold = "%d;" %(ANSI.Bold)
